@@ -15,13 +15,13 @@
 
 
 # import Zope3 interfaces
-from zope.schema.interfaces import ITextLine, IList
+from zope.schema.interfaces import ITextLine
 
 # import local interfaces
 
 # import Zope3 packages
 from zope.interface import implements
-from zope.schema import TextLine, Iterable
+from zope.schema import TextLine
 
 # import local packages
 
@@ -30,7 +30,7 @@ class IPrincipal(ITextLine):
     """Marker interface to define principal ID field"""
 
 
-class IPrincipalList(IList):
+class IPrincipalList(ITextLine):
     """Marker interface to define a list of principal IDs"""
 
 
@@ -38,10 +38,14 @@ class IPrincipalList(IList):
 class Principal(TextLine):
     """Schema field to store a principal ID"""
 
+    _type = (str, unicode, list, tuple)
+
     implements(IPrincipal)
 
 
-class PrincipalList(Iterable):
+class PrincipalList(TextLine):
     """Schema field to store a list of principal IDs"""
 
+    _type = (str, unicode, list, tuple)
+
     implements(IPrincipalList)
